//********************************************************//
//         *_-_ Quadrature de Gauss-Hermite _-_*          //
//********************************************************//

//********************************************************//
//                    Fonction hermite()                  //
//********************************************************//
//***  Renvoie le polynome d'Hermite de degre N
//***
function [Hn] = hermite(N)
//    Ajout de 1 a N pour compenser 
//    le fait que les tableaux sont indicés a
//    partir de 1 en scilab
  N=N+1;
  
//   H est la matrice des coefficients polynomiaux
  H = eye(N,N);
  
//  Remplissage de la premiere colonne de H
  for n = 3:N,
    H(n,1) = -((n-1)-1)*H(n-2,1);
  end;
  
//  Remplissage du reste de H
  for n = 3:N,
    for i = 2:n,
      H(n,i) = H(n-1,i-1) - ((n-1)-1)*H(n-2,i);
    end;
  end;

//    Sortie de la fonction
  Hn = poly(H(N,:),'x','coeff');
endfunction 

//********************************************************//
//                    Fonction racines()                  //
//********************************************************//
//*** Renvoie les N racines du polynome
//*** d'Hermite de degre N
//***
function [xi] = racines(Hn)
  xi = gsort(roots(Hn),'g','i'); //  racines dans 
//                               //  l'ordre decroissant  
//  N = degree(Hn);
//  for i = 1:length(xitmp), 
//    xi(i) = xitmp((N+1)-i); //  racines dans 
//                            //  l'ordre croissant
//  end;
endfunction

//********************************************************//
//                   Fonction poids()                     //
//********************************************************//
//*** Renvoie le i-eme poids de la quadrature de 
//*** Gauss-Hermite a N points
//***
 
//   Cette fonction prend comme argument le polynome 
//   d'Hermite Hn (dans sa forme probaliliste) et renvoie
//   les poids de la quadrature de G-H associée
	   
function [wi] = poids(Hn)
//   N est le degré de Hn
  N = degree(Hn);
  wi = zeros(N);
//   xi contient les racines de Hn
  xi = racines(Hn)
//   Hn1 est le polynome d'hermite de degre N-1
  Hn1 = hermite(N-1);
//   Boucle de calcul des poids
  for i=1:N,
    //wi(i) = sqrt(2.*%pi).*factorial(N)*(1/(N*horner(Hn1,xi(i)))^2); 
    wi(i) = factorial(N)*(1/(N*horner(Hn1,xi(i)))^2);
  end; //end_for
endfunction 
